==> rong-ui-react-0.0.1.tgz: package/es/_hoc/withHashChange.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

var _excluded = ["forwardedRef"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } Object.defineProperty(subClass, "prototype", { value: Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }), writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import ReactDOM from 'react-dom';
import PropTypes from 'prop-types';

function hashChange(WrappedComponent) {
  var HashChange = /*#__PURE__*/function (_Component) {
    _inherits(HashChange, _Component);

    var _super = _createSuper(HashChange);

    function HashChange(props) {
      var _this;

      _classCallCheck(this, HashChange);

      _this = _super.call(this, props);

      _defineProperty(_assertThisInitialized(_this), "handleRemove", function () {
        _this.props.fromInstance && ReactDOM.unmountComponentAtNode(_this.props.portalTarget);
      });

      _this.state = {};
      return _this;
    }

    _createClass(HashChange, [{
      key: "componentDidMount",
      value: function componentDidMount() {
        var _this$props = this.props,
            removeDialogOnHashChange = _this$props.removeDialogOnHashChange,
            fromInstance = _this$props.fromInstance;
        removeDialogOnHashChange && fromInstance && window.addEventListener('hashchange', this.handleRemove);
        removeDialogOnHashChange && fromInstance && window.addEventListener('pushstate', this.handleRemove);
        removeDialogOnHashChange && fromInstance && window.addEventListener('replacestate', this.handleRemove);
        removeDialogOnHashChange && fromInstance && window.addEventListener('popstate', this.handleRemove);
      }
    }, {
      key: "componentWillUnmount",
      value: function componentWillUnmount() {
        var _this$props2 = this.props,
            removeDialogOnHashChange = _this$props2.removeDialogOnHashChange,
            fromInstance = _this$props2.fromInstance;
        removeDialogOnHashChange && fromInstance && window.removeEventListener('hashchange', this.handleRemove);
        removeDialogOnHashChange && fromInstance && window.removeEventListener('pushstate', this.handleRemove);
        removeDialogOnHashChange && fromInstance && window.removeEventListener('replacestate', this.handleRemove);
        removeDialogOnHashChange && fromInstance && window.removeEventListener('popstate', this.handleRemove);
      }
    }, {
      key: "render",
      value: function render() {
        var _this$props3 = this.props,
            forwardedRef = _this$props3.forwardedRef,
            rest = _objectWithoutProperties(_this$props3, _excluded);

        return /*#__PURE__*/React.createElement(WrappedComponent, _extends({
          ref: forwardedRef
        }, rest));
      }
    }]);

    return HashChange;
  }(Component);

  _defineProperty(HashChange, "defaultProps", {
    removeDialogOnHashChange: true
  });

  _defineProperty(HashChange, "propTypes", {
    removeDialogOnHashChange: PropTypes.bool
  });

  return /*#__PURE__*/React.forwardRef(function (props, ref) {
    return /*#__PURE__*/React.createElement(HashChange, _extends({}, props, {
      forwardedRef: ref
    }));
  });
}

export default hashChange;

==> rong-ui-react-0.0.5.tgz: package/es/_hoc/withHashChange.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

var _excluded = ["forwardedRef"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

import React, { Component } from 'react';
import ReactDOM from 'react-dom';
import PropTypes from 'prop-types';

function hashChange(WrappedComponent) {
  var HashChange = /*#__PURE__*/function (_Component) {
    _inherits(HashChange, _Component);

    var _super = _createSuper(HashChange);

    function HashChange(props) {
      var _this;

      _classCallCheck(this, HashChange);

      _this = _super.call(this, props);

      _this.handleRemove = function () {
        _this.props.fromInstance && ReactDOM.unmountComponentAtNode(_this.props.portalTarget);
      };

      _this.state = {};
      return _this;
    }

    _createClass(HashChange, [{
      key: "componentDidMount",
      value: function componentDidMount() {
        var _this$props = this.props,
            removeDialogOnHashChange = _this$props.removeDialogOnHashChange,
            fromInstance = _this$props.fromInstance;
        removeDialogOnHashChange && fromInstance && window.addEventListener('hashchange', this.handleRemove);
        removeDialogOnHashChange && fromInstance && window.addEventListener('pushstate', this.handleRemove);
        removeDialogOnHashChange && fromInstance && window.addEventListener('replacestate', this.handleRemove);
        removeDialogOnHashChange && fromInstance && window.addEventListener('popstate', this.handleRemove);
      }
    }, {
      key: "componentWillUnmount",
      value: function componentWillUnmount() {
        var _this$props2 = this.props,
            removeDialogOnHashChange = _this$props2.removeDialogOnHashChange,
            fromInstance = _this$props2.fromInstance;
        removeDialogOnHashChange && fromInstance && window.removeEventListener('hashchange', this.handleRemove);
        removeDialogOnHashChange && fromInstance && window.removeEventListener('pushstate', this.handleRemove);
        removeDialogOnHashChange && fromInstance && window.removeEventListener('replacestate', this.handleRemove);
        removeDialogOnHashChange && fromInstance && window.removeEventListener('popstate', this.handleRemove);
      }
    }, {
      key: "render",
      value: function render() {
        var _this$props3 = this.props,
            forwardedRef = _this$props3.forwardedRef,
            rest = _objectWithoutProperties(_this$props3, _excluded);

        return /*#__PURE__*/React.createElement(WrappedComponent, _extends({
          ref: forwardedRef
        }, rest));
      }
    }]);

    return HashChange;
  }(Component);

  HashChange.defaultProps = {
    removeDialogOnHashChange: true
  };
  HashChange.propTypes = {
    removeDialogOnHashChange: PropTypes.bool
  };
  return /*#__PURE__*/React.forwardRef(function (props, ref) {
    return /*#__PURE__*/React.createElement(HashChange, _extends({}, props, {
      forwardedRef: ref
    }));
  });
}

export default hashChange;
